summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--perl-install/crypto.pm4
1 files changed, 3 insertions, 1 deletions
diff --git a/perl-install/crypto.pm b/perl-install/crypto.pm
index 4b7e48572..16a011523 100644
--- a/perl-install/crypto.pm
+++ b/perl-install/crypto.pm
@@ -127,8 +127,10 @@ sub getPackages {
log::l("read updates hdlist");
#- keep in mind where is the URL prefix used according to mirror (for install_any::install_urpmi).
$update_medium->{prefix} = "ftp://$mirror" . dir($mirror);
#- (re-)enable the medium to allow install of package.
$update_medium->{selected} = 1;
+ $update_medium->{update} = 1;
return $update_medium;
}
@@ -127,8 +127,10 @@ sub getPackages {
#- keep in mind where is the URL prefix used according to mirror (for install_any::install_urpmi).
$update_medium->{prefix} = "ftp://$mirror" . dir($mirror);
- #- (re-)enable the medium to allow install of package.
+ #- (re-)enable the medium to allow install of package,
+ #- make it an update medium (for install_any::install_urpmi).
$update_medium->{selected} = 1;